@@ -10,6 +10,7 @@ our %Remote = (
         return
             map { Acme::MetaSyntactic::RemoteList::tr_nonword($_) }
             map { s/#/Pound_/g; $_ }
+            map { s/&([aeiouy])(?:acute|grave|circ|uml);/$1/g; $_ }
             $_[0] =~ m!<group id="\d+" status="active">\s*<name>\s*([^<]+)\s*</nam!g;
     },
 );
@@ -31,6 +32,9 @@ Philippe "BooK" Bruhat
 
 Introduced in version 0.49, published on November 21, 2005.
 
+Updated in version 0.56 (28 groups disappeared and 4 groups were created),
+published on January 9, 2006.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -39,317 +43,293 @@ L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
 __DATA__
 # names
+ABE_pm
+AOL_pm
+Aalesund_pm
+Aarau_pm
+Aarhus_pm
+Aberdeen_pm
+Africa_pm
 Albany_pm
 Albuquerque_pm
+Algarve_pm
+Alphen_pm
+Amiga_pm
+Amsterdam_pm
 Anchorage_pm
-AnnArbor_pm
-AOL_pm
+Angola_pm
+Argentina_pm
+Asheville_pm
+Athens_pm
 Atlanta_pm
+Auckland_pm
 Austin_pm
+BH_pm
 Baltimore_pm
+Bangalore_pm
+Bangkok_pm
+Bangsar_pm
+Barcelona_pm
+Basel_pm
+Bath_pm
+Belem_pm
+Belfast_pm
+Belgrade_pm
+Berlin_pm
+Bielefeld_pm
+Birmingham_pm
+Boise_pm
+Bologna_pm
 Boston_pm
 Boulder_pm
+Braga_pm
+Brasil_pm
+Brasilia_pm
+Brisbane_pm
+Bruxelles_pm
+Bucharest_pm
+Budapest_pm
+Buffalo_pm
+Burnaby_pm
+CAMEL_pm
+CaFe_pm
+Calgary_pm
 Cambridge_pm
+Camelot_pm
+Campinas_pm
+Canberra_pm
+Caracas_pm
+Cascais_pm
+Cascavel_pm
+Cedar_Valley_Perl_Mongers_pm
 Champaign_Urbana_pm
+Charleston_pm
 Charlotte_pm
+Chemnitz_pm
 Chicago_pm
-CGI_pm
+China_pm
+ClassicCity_pm
+Clemson_pm
+Cola_pm
+Cologne_pm
+Colombo_pm
+Columbia_pm
+Copenhagen_pm
+CostaRica_pm
+Csy_pm
+DC_pm
 DFW_pm
 Dayton_pm
-DC_pm
+Delhi_pm
+Depok_pm
 DesMoines_pm
+Destin_pm
 Detroit_pm
+Devon_and_Cornwall_pm
+Dominican_Republic_pm
+Dresden_pm
+Dublin_pm
+Edinburgh_pm
+Eindhoven_pm
+Erlangen_pm
+Fortaleza_pm
+Frankfurt_pm
 Gainesville_pm
+Galicia_pm
+Geneva_pm
+German_pm
+Glasgow_pm
+Gombe_pm
 GrandRapids_pm
+Guadalajara_pm
+Guatemala_pm
+Guimaraes_pm
+Hamburg_pm
+HamptonRoads_pm
 Harrisburg_pm
 Hartford_pm
-HudsonValley_pm
-Humboldt_pm
+Helsingborg_pm
+HongKong_pm
 Houston_pm
-Jacksonville_pm
+HudsonValley_pm
+Iassy_pm
+Israel_pm
+Istanbul_pm
+JERL_pm
 JPL_pm
-Knoxville_pm
+Jacksonville_pm
+Jakarta_pm
+Jalisco_pm
+Jerusalem_pm
+Jogja_pm
+Kansai_pm
 KansasCity_pm
+Kaohsiung_pm
+KernCounty_pm
+Kiel_pm
+Kolkata_pm
+Korean_Perl_User_Group_pm
+LA_Belle_pm
+Lafayette_pm
+LagunaNiguel_pm
 LasVegas_pm
+Lawton_pm
+Lebanon_pm
 Lexington_pm
+Lisbon_pm
+Ljubljana_pm
+London_pm
+Los_Angeles_pm
+Lund_pm
+Lyon_pm
+Madras_pm
+Madrid_pm
+Maine_pm
+Malaga_pm
+Malaysia_pm
+Malazgirt_pm
+Maracaibo_pm
+Marseille_pm
+Melbourne_pm
+Mexico_pm
 Miami_pm
-Milwaukee_pm
+Mignon_pm
+MiltonKeynes_pm
 Minneapolis_pm
-Montr_eacute_al_pm
+Mk_pm
+Montreal_pm
+Morris_County_pm
+Moscow_pm
+Munich_pm
+NCSU_pm
+NEPenn_pm
+NE_Oklahoma_Perl_Users_Group_pm
+NH_pm
+NWArkansas_pm
+NewCastle_pm
+NewOrleans_pm
+Niederrhein_pm
+Nomads_pm
+Nordest_pm
+Northfield_pm
+Nottingham_pm
+Oakland_pm
+Oegstgeest_pm
+Oeiras_pm
+OklahomaCity_pm
 Omaha_pm
 OrangeCounty_pm
+Orlando_pm
+Oslo_pm
+PBP_pm
+PDX_pm
+Paderborn_pm
+Pakistan_pm
+Paris_pm
+PerlSemNY_pm
+PhPerl_pm
 Philadelphia_pm
 Phoenix_pm
 PikesPeak_pm
+Pisa_pm
 Pittsburgh_pm
-PDX_pm
+PortoAlegre_pm
+Porto_pm
+Pound_Perl_pm
+Princeton_pm
+Pune_pm
+Purdue_pm
 Raleigh_pm
+Recife_pm
+RenoTahoe_pm
 RhodeIsland_pm
-Rochester_pm
+Richmond_pm
+Rio_pm
+Rockford_pm
+Roederbergweg_pm
+Roma_pm
+Rousse_pm
+SWOK_pm
+Saarland_pm
+Salvador_pm
+Samara_pm
 SanAntonio_pm
 SanDiego_pm
 SanFrancisco_pm
-Seattle_pm
-Sonoma_pm
-StLouis_pm
-TampaBay_pm
-Tallahassee_pm
-ThousandOaks_pm
-Toronto_pm
-Vancouver_pm
-Winnipeg_pm
-Sao_Paulo_pm
-Aarhus_pm
-Amsterdam_pm
-Bath_pm
-Belfast_pm
-Braga_pm
-Edinburgh_pm
-Glasgow_pm
-Goteborg_pm
-Copenhagen_pm
-Lisbon_pm
-London_pm
-Lund_pm
-Moscow_pm
-Munich_pm
-Paris_pm
-Porto_pm
-Roma_pm
-Stockholm_pm
-Vienna_pm
-Auckland_pm
-Brisbane_pm
-CentralCoast_pm
-Malaysia_pm
-Melbourne_pm
-Perth_pm
-Sydney_pm
-Bangkok_pm
-Delhi_pm
-HongKong_pm
-Pune_pm
-Tokyo_pm
-Israel_pm
-Algarve_pm
-Oxford_pm
-Lawton_pm
-Columbia_pm
-Guimaraes_pm
-Sofia_pm
-Caracas_pm
-Cola_pm
-Bangalore_pm
-Oslo_pm
-Madrid_pm
-PortoAlegre_pm
-Budapest_pm
-Purdue_pm
-Frankfurt_pm
-Richmond_pm
-HamptonRoads_pm
-Istanbul_pm
-Tijuana_pm
-Kolkata_pm
-NewOrleans_pm
-Kansai_pm
-Aalesund_pm
-OklahomaCity_pm
-Madras_pm
-Burnaby_pm
-Granada_pm
-Seneca_pm
-Ulm_pm
-Rio_pm
-Taipei_pm
-Los_Angeles_pm
-Athens_pm
-NWArkansas_pm
-Oakland_pm
-Birmingham_pm
-Bloomington_Normal_pm
-Colombo_pm
-Bangsar_pm
-RenoTahoe_pm
-NCSU_pm
-Toulouse_pm
-Niederrhein_pm
-Izmir_pm
-kraljevo_pm
-iran_pm
-Taichung_pm
-Barcelona_pm
-Tyneside_pm
 Santa_Fe_Los_Alamos_pm
-Victoria_pm
-Rousse_pm
-Brasilia_pm
-Wellington_pm
-Marseille_pm
-Oeiras_pm
+Santiago_pm
+SantoDomingo_pm
+Sao_Paulo_pm
+Seattle_pm
+Seneca_pm
+Shadrinsk_pm
+Shibuya_pm
+SiouxLand_pm
+SoCo_pm
+Sonoma_pm
+SouthFlorida_pm
+SpringfieldMO_pm
+Sri_Lanka_pm
+StLouis_pm
 StPaul_pm
-Prague_pm
+Stockholm_pm
+Stuttgart_pm
+Sydney_pm
+Taichung_pm
+Taipei_pm
+Tallahassee_pm
+TampaBay_pm
+Taubate_pm
+Tempe_East_Valley_Perlmongers_pm
+Terere_pm
+Thane_pm
+ThousandOaks_pm
+Tijuana_pm
+Tokyo_pm
+Toronto_pm
+Toulouse_pm
+Tucson_pm
+Ulm_pm
+Valladolid_pm
 ValleKas_pm
 ValleyPerl_pm
-Guadalajara_pm
-Dublin_pm
-Morris_County_pm
-Berlin_pm
-Tulsa_pm
-WestTexas_pm
-Bologna_pm
-Clemson_pm
-Shadrinsk_pm
-Rioja_pm
-WYPUG_pm
-Jogja_pm
-stttelkom_pm
-Nordest_pm
-CaFe_pm
-SiouxLand_pm
-Malaga_pm
-Tucson_pm
-Devon_and_Cornwall_pm
-CostaRica_pm
-Nomads_pm
-Lyon_pm
-Basel_pm
-DBI_pm
-PerlSemNY_pm
-Bruxelles_pm
-SouthFlorida_pm
-CAMEL_pm
-Belgrade_pm
-bali_pm
-Yuma_pm
-Zurich_pm
-China_pm
-Fortaleza_pm
-Boise_pm
-Destin_pm
-NEPenn_pm
-Gabrovo_pm
-Bucharest_pm
-WhiteMountain_pm
-NH_pm
-Kaohsiung_pm
-Depok_pm
-Mignon_pm
-Alphen_pm
-kw_pm
-SpringfieldMO_pm
-Canberra_pm
-Terere_pm
-Dresden_pm
-Leuven_pm
-Maine_pm
-Cologne_pm
-Hamburg_pm
-Iassy_pm
-Cascavel_pm
-Guatemala_pm
-Helsingborg_pm
-Csy_pm
-Lebanon_pm
-Calgary_pm
-SWOK_pm
-Galicia_pm
-Buffalo_pm
+Vancouver_pm
+Viana_pm
+Victoria_pm
+Vienna_pm
+Vitoria_pm
 Vlaanderen_pm
-NewCastle_pm
+WYPUG_pm
+Wellington_pm
+WhiteMountain_pm
+Winnipeg_pm
+Yerevan_pm
+Yuma_pm
 ZA_pm
-Jalisco_pm
-Saarland_pm
-Shibuya_pm
-German_pm
-Kiel_pm
-Camelot_pm
-Malazgirt_pm
-KernCounty_pm
-Africa_pm
-Princeton_pm
-Pisa_pm
-LagunaNiguel_pm
-PhPerl_pm
-Dominican_Republic_pm
-Recife_pm
-arnhem_pm
-Thane_pm
-Stuttgart_pm
-Brasil_pm
-torino_pm
-Oegstgeest_pm
-salerno_pm
-Gombe_pm
-dahut_pm
-Orlando_pm
-ClassicCity_pm
-Northfield_pm
-Samara_pm
-SantoDomingo_pm
-Jakarta_pm
-Roederbergweg_pm
-Mexico_pm
-Korean_Perl_User_Group_pm
-may_pm
-Valladolid_pm
-Kamloops_pm
-Pakistan_pm
-tutorial_pm_org_pm
-austria_marchfeld_pm
-JERL_pm
-rubbercity_pm
-Bielefeld_pm
-Cedar_Valley_Perl_Mongers_pm
 aalborg_pm
-plovdiv_pm
-Tempe_East_Valley_Perlmongers_pm
+ankara_pm
+arnhem_pm
+austria_marchfeld_pm
+bali_pm
+brazosvalley_pm
+cypriots_pm
+dahut_pm
+groningen_pm
+hanoi_pm
+innsbruck_pm
+iran_pm
+italia_pm
 kampala_pm
-StonyBrook_pm
-Maracaibo_pm
-LA_Belle_pm
+kraljevo_pm
+kw_pm
+may_pm
+mytutorial_pm
 ooubafsan_pm
 ph_pm
-hanoi_pm
-Sri_Lanka_pm
-ABE_pm
-mytutorial_pm
-Mk_pm
-mississippi_pm
-Angola_pm
-NE_Oklahoma_Perl_Users_Group_pm
-Nottingham_pm
-Yerevan_pm
-nova_pm
-Eindhoven_pm
+plovdiv_pm
+rubbercity_pm
+salerno_pm
+stttelkom_pm
+torino_pm
 turkperl_pm
-Jerusalem_pm
-Vitoria_pm
-cypriots_pm
-ankara_pm
-italia_pm
-Geneva_pm
-Aarau_pm
-Cascais_pm
-Ljubljana_pm
-Belem_pm
-Aberdeen_pm
-Paderborn_pm
-Campinas_pm
-BH_pm
-Argentina_pm
-brazosvalley_pm
-groningen_pm
-innsbruck_pm
-Santiago_pm
-Pound_Perl_pm
-Erlangen_pm
-Viana_pm
-Salvador_pm
-Taubate_pm
-Lafayette_pm
-Amiga_pm
-Charleston_pm
-Asheville_pm
-Chemnitz_pm
-MiltonKeynes_pm
+tutorial_pm_org_pm
